// Author : Seb Lee-Delisle
// Blog : www.sebleedelisle.com
// Company : www.pluginmedia.net
// Mail : sebleedelisle@gmail.com
//
// This work is licensed under a Creative Commons 2.0  non-commercial share-alike License.

// Full details at 
// http://creativecommons.org/licenses/by-nc-sa/2.0/uk/

package net.pluginmedia.pv3d
{
	import flash.display.BitmapData;
	import flash.display.Sprite;
	import flash.filters.BlurFilter;
	import flash.geom.Matrix;
	
	import org.papervision3d.core.geom.Particles;
	import org.papervision3d.core.math.Number3D;
	import org.papervision3d.materials.special.BitmapParticleMaterial;
	import org.papervision3d.materials.special.ParticleMaterial;
	

	public class SnowStorm extends Particles
	{
		public var wind 			: Number3D = Number3D.ZERO; 
		public var maxFlakes 		: int; 
		public var defaultFlakeSize	: Number; 
		public var cubeSize 		: Number ; 
		
		public var flakeMaterial : ParticleMaterial; 
		
		public function SnowStorm(quantity:int=200, flakeSize:Number=32, cubesize : Number = 400)
		{
			super("SnowStorm"); 
			defaultFlakeSize = flakeSize; 
			maxFlakes = quantity; 
			cubeSize = cubesize; 
			initMaterials(); 
			
		}
		
		
		public function initMaterials() : void 
		{
			var flakesprite : Sprite = new Sprite(); 
			
			flakesprite.graphics.lineStyle(16,0xffffff); 
			flakesprite.graphics.moveTo(0,0); 
			flakesprite.graphics.lineTo(0.2,0.2);
			flakesprite.filters = [new BlurFilter(24,24,2)]; 
			
			var bitmapdata : BitmapData = new BitmapData(64,64,true,0x00000000); 
			
			bitmapdata.draw(flakesprite, new Matrix(2,0,0,2,32,32));
			
			flakeMaterial = new BitmapParticleMaterial(bitmapdata); 
			
			
		}
		
		public function update() : void
		{
			if(particles.length < maxFlakes)
			{
				var flake : SnowFlake = new SnowFlake(flakeMaterial,defaultFlakeSize,getRandomPos(), -cubeSize>>1, getRandomPos()); 		
				addParticle(flake); 
				
			}
			
			
			for(var i :int = 0; i<particles.length; i++)
			{
				var snowflake : SnowFlake = particles[i] as SnowFlake; 
				snowflake.update(cubeSize); 
				
				
			}
			
		}
		
		public function get snowFlakes() : Array
		{
			return particles; 
		}
		
		public function getRandomPos() : Number 
		{
			return (Math.random()*cubeSize)-(cubeSize>>1);
			
		}
		
		
	}
}